@@ -1,29 +1,30 @@
-from .Audio import busy
-from .Audio import load
-from .Audio import play
-from .Audio import pos
-from .Audio import rewind
-from .Audio import stop
-from .Audio import pause
-from .Audio import unpause
-from .Audio import volume
+from Rafflesia.Audio import busy
+from Rafflesia.Audio import effects
+from Rafflesia.Audio import load
+from Rafflesia.Audio import play
+from Rafflesia.Audio import pos
+from Rafflesia.Audio import queue
+from Rafflesia.Audio import rewind
+from Rafflesia.Audio import stop
+from Rafflesia.Audio import pause
+from Rafflesia.Audio import unpause
+from Rafflesia.Audio import volume
 import pygame
 
-pygame.mixer.set_num_channels(2048)
-
 
 class AudioManager:
     def __init__(self, dev=False):
-        self.channelidlist = []
         self.dev = dev
+        pygame.init()
+        pygame.mixer.set_num_channels(2048)
         super(AudioManager, self).__init__()
 
-    def shortplay(self, filepath, channelname):
-        play.shortplay(filepath)
-
     def long_load(self, filepath):
         load.long_load(filepath, self.dev)
 
+    def long_queue(self, filepath):
+        queue.long_queue(filepath, self.dev)
+
     def long_play(self, loops=0, start=0.0, infinityloop=False):
         play.long_play(loops, start, infinityloop, self.dev)
 
@@ -54,4 +55,5 @@ class AudioManager:
     def long_set_pos(self, value):
         pos.long_set_pos(value, self.dev)
 
-
+    def long_fadeout(self, value):
+        effects.long_fadeout(value, self.dev)
